@@ -1,4 +1,4 @@
-/* $Id: rmagick.h,v 1.273 2009/06/04 23:18:57 rmagick Exp $ */
+/* $Id: rmagick.h,v 1.275 2009/07/23 22:55:57 rmagick Exp $ */
 /*=============================================================================
 |               Copyright (C) 2009 by Timothy P. Hunter
 | Name:     rmagick.h
@@ -873,6 +873,7 @@ extern VALUE Image_properties(VALUE);
 extern VALUE Image_bilevel_channel(int, VALUE *, VALUE);
 extern VALUE Image_black_threshold(int, VALUE *, VALUE);
 extern VALUE Image_blend(int, VALUE *, VALUE);
+extern VALUE Image_blue_shift(int, VALUE *, VALUE);
 extern VALUE Image_blur_image(int, VALUE *, VALUE);
 extern VALUE Image_blur_channel(int, VALUE *, VALUE);
 extern VALUE Image_border(VALUE, VALUE, VALUE, VALUE);
@@ -900,6 +901,7 @@ extern VALUE Image_composite_affine(VALUE, VALUE, VALUE);
 extern VALUE Image_composite_bang(int, VALUE *, VALUE);
 extern VALUE Image_composite_channel(int, VALUE *, VALUE);
 extern VALUE Image_composite_channel_bang(int, VALUE *, VALUE);
+extern VALUE Image_composite_mathematics(int, VALUE *, VALUE);
 extern VALUE Image_composite_tiled(int, VALUE *, VALUE);
 extern VALUE Image_composite_tiled_bang(int, VALUE *, VALUE);
 extern VALUE Image_compress_colormap_bang(VALUE);
