@@ -1,6 +1,6 @@
-/* $Id: rminfo.c,v 1.71 2008/05/21 22:32:41 rmagick Exp $ */
+/* $Id: rminfo.c,v 1.78 2009/03/04 00:35:19 rmagick Exp $ */
 /*============================================================================\
-|                Copyright (C) 2008 by Timothy P. Hunter
+|                Copyright (C) 2009 by Timothy P. Hunter
 | Name:     rminfo.c
 | Author:   Tim Hunter
 | Purpose:  Info class method definitions for RMagick.
@@ -162,6 +162,23 @@ static VALUE set_dbl_option(VALUE self, const char *option, VALUE value)
 }
 
 
+/*
+    Static:     pixel_packet_to_hexname(pp, name)
+    Purpose:    convert a PixelPacket to a hex-format color name
+*/
+#if 0
+static char *pixel_packet_to_hexname(PixelPacket *pp, char *name)
+{
+    MagickPixelPacket mpp;
+
+    GetMagickPixelPacket(NULL, &mpp);
+    rm_set_magick_pixel_packet(pp, &mpp);
+    (void) GetColorTuple(&mpp, MagickTrue, name);
+    return name;
+}
+#endif
+
+
 DEF_ATTR_ACCESSOR(Info, antialias, bool)
 
 /*
@@ -278,7 +295,7 @@ Info_aset(int argc, VALUE *argv, VALUE self)
     else
     {
         /* Allow any argument that supports to_s */
-        value = rb_funcall(value, rm_ID_to_s, 0);
+        value = rm_to_s(value);
         value_p = StringValuePtr(value);
 
         (void) RemoveImageOption(info, ckey);
@@ -365,9 +382,10 @@ Info_background_color(VALUE self)
     Info *info;
 
     Data_Get_Struct(self, Info, info);
-    return PixelPacket_to_Color_Name_Info(info, &info->background_color);
+    return rm_pixelpacket_to_color_name_info(info, &info->background_color);
 }
 
+
 /*
     Method:     Info#background_color=<aString>
     Purpose:    set the background color
@@ -377,9 +395,11 @@ VALUE
 Info_background_color_eq(VALUE self, VALUE bc_arg)
 {
     Info *info;
+    //char colorname[MaxTextExtent];
 
     Data_Get_Struct(self, Info, info);
     Color_to_PixelPacket(&info->background_color, bc_arg);
+    //SetImageOption(info, "background", pixel_packet_to_hexname(&info->background_color, colorname));
     return self;
 }
 
@@ -394,7 +414,7 @@ Info_border_color(VALUE self)
     Info *info;
 
     Data_Get_Struct(self, Info, info);
-    return PixelPacket_to_Color_Name_Info(info, &info->border_color);
+    return rm_pixelpacket_to_color_name_info(info, &info->border_color);
 }
 
 /*
@@ -406,9 +426,11 @@ VALUE
 Info_border_color_eq(VALUE self, VALUE bc_arg)
 {
     Info *info;
+    //char colorname[MaxTextExtent];
 
     Data_Get_Struct(self, Info, info);
     Color_to_PixelPacket(&info->border_color, bc_arg);
+    //SetImageOption(info, "bordercolor", pixel_packet_to_hexname(&info->border_color, colorname));
     return self;
 }
 
@@ -541,7 +563,7 @@ Info_define(int argc, VALUE *argv, VALUE self)
     {
         case 3:
             /* Allow any argument that supports to_s */
-            fmt_arg = rb_funcall(argv[2], rm_ID_to_s, 0);
+            fmt_arg = rb_String(argv[2]);
             value = (const char *)StringValuePtr(fmt_arg);
         case 2:
             key = rm_str2cstr(argv[1], &key_l);
@@ -665,7 +687,7 @@ Info_density_eq(VALUE self, VALUE density_arg)
         return self;
     }
 
-    density = rb_funcall(density_arg, rm_ID_to_s, 0);
+    density = rm_to_s(density_arg);
     dens = StringValuePtr(density);
     if (!IsGeometry(dens))
     {
@@ -736,6 +758,25 @@ static struct
 };
 #define N_DISPOSE_OPTIONS (int)(sizeof(Dispose_Option)/sizeof(Dispose_Option[0]))
 
+
+DisposeType rm_dispose_to_enum(const char *name)
+{
+    DisposeType dispose = UndefinedDispose;
+    int x;
+
+    for (x = 0; x < N_DISPOSE_OPTIONS; x++)
+    {
+        if (strcmp(Dispose_Option[x].string, name) == 0)
+        {
+            dispose = Dispose_Option[x].enumerator;
+            break;
+        }
+    }
+
+    return dispose;
+}
+
+
 VALUE
 Info_dispose(VALUE self)
 {
@@ -805,6 +846,38 @@ Info_dispose_eq(VALUE self, VALUE disp)
 DEF_ATTR_ACCESSOR(Info, dither, bool)
 
 
+/*
+    Method:     Info#endian
+                Info#endian = Maigck::MSBEndian or LSBEndian
+    Purpose:    Set the Image::Info#endian attribute for reading
+*/
+VALUE
+Info_endian(VALUE self)
+{
+    Info *info;
+
+    Data_Get_Struct(self, Info, info);
+    return EndianType_new(info->endian);
+}
+
+
+VALUE
+Info_endian_eq(VALUE self, VALUE endian)
+{
+    Info *info;
+    EndianType type = UndefinedEndian;
+
+    if (endian != Qnil)
+    {
+        VALUE_TO_ENUM(endian, type, EndianType);
+    }
+
+    Data_Get_Struct(self, Info, info);
+    info->endian = type;
+    return self;
+}
+
+
 /*
     Method:     aString=Info#extract
                 Info#extract=aString
@@ -830,7 +903,7 @@ Info_extract_eq(VALUE self, VALUE extract_arg)
         return self;
     }
 
-    extract = rb_funcall(extract_arg, rm_ID_to_s, 0);
+    extract = rm_to_s(extract_arg);
     extr = StringValuePtr(extract);
     if (!IsGeometry(extr))
     {
@@ -1027,6 +1100,25 @@ static struct
 };
 #define N_GRAVITY_OPTIONS (int)(sizeof(Gravity_Option)/sizeof(Gravity_Option[0]))
 
+
+GravityType rm_gravity_to_enum(const char *name)
+{
+    GravityType gravity = UndefinedGravity;
+    int x;
+
+    for (x = 0; x < N_GRAVITY_OPTIONS; x++)
+    {
+        if (strcmp(name, Gravity_Option[x].string) == 0)
+        {
+            gravity = Gravity_Option[x].enumerator;
+            break;
+        }
+    }
+
+    return gravity;
+}
+
+
 VALUE Info_gravity(VALUE self)
 {
     Info *info;
@@ -1166,7 +1258,7 @@ Info_matte_color(VALUE self)
     Info *info;
 
     Data_Get_Struct(self, Info, info);
-    return PixelPacket_to_Color_Name_Info(info, &info->matte_color);
+    return rm_pixelpacket_to_color_name_info(info, &info->matte_color);
 }
 
 /*
@@ -1178,9 +1270,11 @@ VALUE
 Info_matte_color_eq(VALUE self, VALUE matte_arg)
 {
     Info *info;
+    //char colorname[MaxTextExtent];
 
     Data_Get_Struct(self, Info, info);
     Color_to_PixelPacket(&info->matte_color, matte_arg);
+    //SetImageOption(info, "mattecolor", pixel_packet_to_hexname(&info->matte_color, colorname));
     return self;
 }
 
@@ -1283,7 +1377,7 @@ Info_origin_eq(VALUE self, VALUE origin_arg)
         return self;
     }
 
-    origin_str = rb_funcall(origin_arg, rm_ID_to_s, 0);
+    origin_str = rm_to_s(origin_arg);
     origin = GetPageGeometry(StringValuePtr(origin_str));
 
     if (IsGeometry(origin) == MagickFalse)
@@ -1300,11 +1394,9 @@ VALUE
 Info_page(VALUE self)
 {
     Info *info;
-    const char *page;
 
     Data_Get_Struct(self, Info, info);
-    page = GetImageOption(info, "page");
-    return page ? rb_str_new2(page) : Qnil;
+    return info->page ? rb_str_new2(info->page) : Qnil;
 
 }
 
@@ -1326,7 +1418,7 @@ Info_page_eq(VALUE self, VALUE page_arg)
         info->page = NULL;
         return self;
     }
-    geom_str = rb_funcall(page_arg, rm_ID_to_s, 0);
+    geom_str = rm_to_s(page_arg);
     geometry=GetPageGeometry(StringValuePtr(geom_str));
     if (*geometry == '\0')
     {
@@ -1335,7 +1427,6 @@ Info_page_eq(VALUE self, VALUE page_arg)
         return self;
     }
     magick_clone_string(&info->page, geometry);
-    (void) SetImageOption(info, "page", StringValuePtr(geom_str));
 
     return self;
 }
@@ -1391,9 +1482,45 @@ Info_sampling_factor_eq(VALUE self, VALUE sampling_factor)
     return self;
 }
 
-DEF_ATTR_ACCESSOR(Info, scene, ulong)
+
+/*
+    Method:     Info#scene
+                Info#scene=
+    Purpose:    Get/Set the scene number
+*/
+VALUE
+Info_scene(VALUE self)
+{
+    Info *info;
+
+    Data_Get_Struct(self, Info, info);
+    return  ULONG2NUM(info->scene);
+}
+
+
+VALUE
+Info_scene_eq(VALUE self, VALUE scene)
+{
+    Info *info;
+    char buf[25];
+
+    Data_Get_Struct(self, Info, info);
+    info->scene = NUM2ULONG(scene);
+
+#if defined(HAVE_SNPRINTF)
+    (void) snprintf(buf, sizeof(buf), "%-ld", info->scene);
+#else
+    (void) sprintf(buf, "%-l", info->scene);
+#endif
+    (void) SetImageOption(info, "scene", buf);
+
+    return self;
+}
+
+
 DEF_ATTR_READER(Info, server_name, str)
 
+
 /*
     Method:     Info#server_name=<aString>
     Purpose:    Set the server name
@@ -1442,7 +1569,7 @@ Info_size_eq(VALUE self, VALUE size_arg)
         return self;
     }
 
-    size = rb_funcall(size_arg, rm_ID_to_s, 0);
+    size = rm_to_s(size_arg);
     sz = StringValuePtr(size);
     if (!IsGeometry(sz))
     {
@@ -1549,7 +1676,7 @@ Info_tile_offset_eq(VALUE self, VALUE offset)
     volatile VALUE offset_str;
     char *tile_offset;
 
-    offset_str = rb_funcall(offset, rm_ID_to_s, 0);
+    offset_str = rm_to_s(offset);
     tile_offset = StringValuePtr(offset_str);
     if (!IsGeometry(tile_offset))
     {
@@ -1564,6 +1691,39 @@ Info_tile_offset_eq(VALUE self, VALUE offset)
 }
 
 
+/*
+    Method:     Info#transparent_color
+    Purpose:    return the name of the transparent color as a String
+    Note:       Compare with Image#transparent_color!
+*/
+VALUE
+Info_transparent_color(VALUE self)
+{
+    Info *info;
+
+    Data_Get_Struct(self, Info, info);
+    return rm_pixelpacket_to_color_name_info(info, &info->transparent_color);
+}
+
+
+/*
+    Method:     Info#transparent_color=<aString>
+    Purpose:    set the transparent color
+    Raises:     ArgumentError
+*/
+VALUE
+Info_transparent_color_eq(VALUE self, VALUE tc_arg)
+{
+    Info *info;
+    //char colorname[MaxTextExtent];
+
+    Data_Get_Struct(self, Info, info);
+    Color_to_PixelPacket(&info->transparent_color, tc_arg);
+    //SetImageOption(info, "transparent", pixel_packet_to_hexname(&info->transparent_color, colorname));
+    return self;
+}
+
+
 /*
     Method:     Image::Info#tile_offset
     Purpose:    returns tile_offset attribute values
