@@ -1,4 +1,4 @@
-/* $Id: rmmain.c,v 1.296 2009/06/19 22:07:05 rmagick Exp $ */
+/* $Id: rmmain.c,v 1.299 2009/09/05 20:01:08 rmagick Exp $ */
 /*============================================================================\
 |                Copyright (C) 2009 by Timothy P. Hunter
 | Name:     rmmain.c
@@ -264,6 +264,7 @@ Init_RMagick2(void)
     rb_define_method(Class_Image, "bilevel_channel", Image_bilevel_channel, -1);
     rb_define_method(Class_Image, "black_threshold", Image_black_threshold, -1);
     rb_define_method(Class_Image, "blend", Image_blend, -1);
+    rb_define_method(Class_Image, "blue_shift", Image_blue_shift, -1);
     rb_define_method(Class_Image, "blur_image", Image_blur_image, -1);
     rb_define_method(Class_Image, "blur_channel", Image_blur_channel, -1);
     rb_define_method(Class_Image, "border", Image_border, 3);
@@ -292,6 +293,7 @@ Init_RMagick2(void)
     rb_define_method(Class_Image, "composite_affine", Image_composite_affine, 2);
     rb_define_method(Class_Image, "composite_channel", Image_composite_channel, -1);
     rb_define_method(Class_Image, "composite_channel!", Image_composite_channel_bang, -1);
+    rb_define_method(Class_Image, "composite_mathematics", Image_composite_mathematics, -1);
     rb_define_method(Class_Image, "composite_tiled", Image_composite_tiled, -1);
     rb_define_method(Class_Image, "composite_tiled!", Image_composite_tiled_bang, -1);
     rb_define_method(Class_Image, "compress_colormap!", Image_compress_colormap_bang, 0);
@@ -977,6 +979,12 @@ Init_RMagick2(void)
         ENUMERATOR(HueCompositeOp)
         ENUMERATOR(InCompositeOp)
         ENUMERATOR(LightenCompositeOp)
+#if defined(HAVE_ENUM_LINEARBURNCOMPOSITEOP)
+        ENUMERATOR(LinearBurnCompositeOp)
+#endif
+#if defined(HAVE_ENUM_LINEARDODGECOMPOSITEOP)
+        ENUMERATOR(LinearDodgeCompositeOp)
+#endif
         ENUMERATOR(LinearLightCompositeOp)
         ENUMERATOR(LuminizeCompositeOp)
         ENUMERATOR(MinusCompositeOp)
@@ -985,6 +993,12 @@ Init_RMagick2(void)
         ENUMERATOR(OutCompositeOp)
         ENUMERATOR(OverCompositeOp)
         ENUMERATOR(OverlayCompositeOp)
+#if defined(HAVE_ENUM_PEGTOPLIGHTCOMPOSITEOP)
+        ENUMERATOR(PegtopLightCompositeOp)
+#endif
+#if defined(HAVE_ENUM_PINLIGHTCOMPOSITEOP)
+        ENUMERATOR(PinLightCompositeOp)
+#endif
         ENUMERATOR(PlusCompositeOp)
         ENUMERATOR(ReplaceCompositeOp)    // synonym for CopyCompositeOp
         ENUMERATOR(SaturateCompositeOp)
@@ -997,6 +1011,9 @@ Init_RMagick2(void)
         ENUMERATOR(SrcOverCompositeOp)
         ENUMERATOR(SubtractCompositeOp)
         ENUMERATOR(ThresholdCompositeOp)
+#if defined(HAVE_ENUM_VIVIDLIGHTCOMPOSITEOP)
+        ENUMERATOR(VividLightCompositeOp)
+#endif
         ENUMERATOR(XorCompositeOp)
     END_ENUM
 
@@ -1004,6 +1021,12 @@ Init_RMagick2(void)
     DEF_ENUM(CompressionType)
         ENUMERATOR(UndefinedCompression)
         ENUMERATOR(NoCompression)
+#if defined(HAVE_ENUM_B44COMPRESSION)
+        ENUMERATOR(B44Compression)
+#endif
+#if defined(HAVE_ENUM_B44ACOMPRESSION)
+        ENUMERATOR(B44ACompression)
+#endif
         ENUMERATOR(BZipCompression)
 #if defined(HAVE_ENUM_DXT1COMPRESSION)
         ENUMERATOR(DXT1Compression)
@@ -1020,8 +1043,17 @@ Init_RMagick2(void)
         ENUMERATOR(JPEG2000Compression)
         ENUMERATOR(LosslessJPEGCompression)
         ENUMERATOR(LZWCompression)
+#if defined(HAVE_ENUM_PIZCOMPRESSION)
+        ENUMERATOR(PizCompression)
+#endif
+#if defined(HAVE_ENUM_PXR24COMPRESSION)
+        ENUMERATOR(Pxr24Compression)
+#endif
         ENUMERATOR(RLECompression)
         ENUMERATOR(ZipCompression)
+#if defined(HAVE_ENUM_ZIPSCOMPRESSION)
+        ENUMERATOR(ZipSCompression)
+#endif
     END_ENUM
 
     // DecorationType constants
@@ -1606,7 +1638,7 @@ version_constants(void)
     rb_define_const(Module_Magick, "Version", str);
 
     sprintf(long_version,
-            "This is %s ($Date: 2009/06/19 22:07:05 $) Copyright (C) 2009 by Timothy P. Hunter\n"
+            "This is %s ($Date: 2009/09/05 20:01:08 $) Copyright (C) 2009 by Timothy P. Hunter\n"
             "Built with %s\n"
             "Built for %s\n"
             "Web page: http://rmagick.rubyforge.org\n"
