@@ -1,6 +1,6 @@
-# $Id: RMagick.rb,v 1.72 2008/06/08 13:41:39 rmagick Exp $
+# $Id: RMagick.rb,v 1.82 2009/09/05 19:59:40 rmagick Exp $
 #==============================================================================
-#                  Copyright (C) 2008 by Timothy P. Hunter
+#                  Copyright (C) 2009 by Timothy P. Hunter
 #   Name:       RMagick.rb
 #   Author:     Tim Hunter
 #   Purpose:    Extend Ruby to interface with ImageMagick.
@@ -24,7 +24,14 @@ def Magick.formats(&block)
 end
 
 class << self
-    attr_writer :trace_proc
+    # remove reference to the proc at exit
+    def trace_proc=(p)
+       if @trace_proc.nil? && !p.nil? && !@exit_block_set_up
+          at_exit { @trace_proc = nil }
+          @exit_block_set_up = true
+       end
+       @trace_proc = p
+    end
 end
 
 # Geometry class and related enum constants
@@ -364,6 +371,30 @@ class Draw
         primitive "gravity #{GRAVITY_NAMES[grav.to_i]}"
     end
 
+    # IM 6.4.8-3 and later
+    def interword_spacing(space)
+        begin
+            Float(space)
+        rescue ArgumentError
+            Kernel.raise ArgumentError, "invalid value for interword_spacing"
+        rescue TypeError
+            Kernel.raise TypeError, "can't convert #{space.class} into Float"
+        end
+        primitive "interword-spacing #{space}"
+    end
+
+    # IM 6.4.8-3 and later
+    def kerning(space)
+        begin
+            Float(space)
+        rescue ArgumentError
+            Kernel.raise ArgumentError, "invalid value for kerning"
+        rescue TypeError
+            Kernel.raise TypeError, "can't convert #{space.class} into Float"
+        end
+        primitive "kerning #{space}"
+    end
+
     # Draw a line
     def line(startX, startY, endX, endY)
         primitive "line " + sprintf("%g,%g %g,%g", startX, startY, endX, endY)
@@ -734,6 +765,8 @@ end # module Magick::IPTC
 class Image
     include Comparable
 
+    alias_method :affinity, :remap
+
     # Provide an alternate version of Draw#annotate, for folks who
     # want to find it in this class.
     def annotate(draw, width, height, x, y, text, &block)
@@ -1409,7 +1442,7 @@ public
     end
 
     [:at, :each, :each_index, :empty?, :fetch,
-     :first, :hash, :include?, :index, :length, :nitems, :rindex, :sort!].each do |mth|
+     :first, :hash, :include?, :index, :length, :rindex, :sort!].each do |mth|
         module_eval <<-END_SIMPLE_DELEGATES
             def #{mth}(*args, &block)
                 @images.#{mth}(*args, &block)
@@ -1418,6 +1451,13 @@ public
     end
     alias_method :size, :length
 
+    # Array#nitems is not available in 1.9
+    if Array.instance_methods.include?("nitems")
+       def nitems()
+          @images.nitems()
+       end
+    end
+
     def clear
         @scene = nil
         @images.clear
@@ -1467,6 +1507,9 @@ public
     alias_method :map!, :collect!
     alias_method :__map__!, :collect!
 
+    # ImageMagic used affinity in 6.4.3, switch to remap in 6.4.4.
+    alias_method :affinity, :remap
+
     def compact
         current = get_current()
         ilist = self.class.new
@@ -1571,11 +1614,11 @@ public
     end
 
     # Initialize new instances
-    def initialize(*filenames)
+    def initialize(*filenames, &block)
         @images = []
         @scene = nil
         filenames.each { |f|
-            Magick::Image.read(f).each { |n| @images << n }
+            Magick::Image.read(f, &block).each { |n| @images << n }
             }
         if length > 0
             @scene = length - 1     # last image in array
@@ -1621,6 +1664,19 @@ public
         return a
     end
 
+    # Custom marshal/unmarshal for Ruby 1.8.
+    def marshal_dump()
+       ary = [@scene]
+       @images.each {|i| ary << Marshal.dump(i)}
+       ary
+    end
+
+    def marshal_load(ary)
+       @scene = ary.shift
+       @images = []
+       ary.each {|a| @images << Marshal.load(a)}
+    end
+
     # The ImageList class supports the Magick::Image class methods by simply sending
     # the method to the current image. If the method isn't explicitly supported,
     # send it to the current image in the array. If there are no images, send
@@ -1833,6 +1889,37 @@ public
 
 end # Magick::ImageList
 
+
+#  Collects non-specific optional method arguments
+class OptionalMethodArguments
+    def initialize(img)
+       @img = img
+    end
+
+    # miscellaneous options like -verbose
+    def method_missing(mth, val)
+       @img.define(mth.to_s.tr('_', '-'), val)
+    end
+
+    # set(key, val) corresponds to -set option:key val
+    def define(key, val = nil)
+       @img.define(key, val)
+    end
+
+    # accepts Pixel object or color name
+    def highlight_color=(color)
+       color = @img.to_color(color) if color.respond_to?(:to_color)
+       @img.define("highlight-color", color)
+    end
+
+    # accepts Pixel object or color name
+    def lowlight_color=(color)
+       color = @img.to_color(color) if color.respond_to?(:to_color)
+       @img.define("lowlight-color", color)
+    end
+end
+
+
 # Example fill class. Fills the image with the specified background
 # color, then crosshatches with the specified crosshatch color.
 # @dist is the number of pixels between hatch lines.
