@@ -1,5 +1,5 @@
-# $Id: misc.rb,v 1.12 2008/02/24 18:26:36 rmagick Exp $
-# Copyright (C) 2008 Timothy P. Hunter
+# $Id: misc.rb,v 1.15 2009/02/28 23:52:27 rmagick Exp $
+# Copyright (C) 2009 Timothy P. Hunter
 module Magick
     class RVG
 
@@ -104,9 +104,10 @@ module Magick
                 end
 
                 def glyph_metrics(glyph_orientation, glyph)
-                    glyph_metrics = @ctx.shadow.get_type_metrics(glyph)
-                    h = glyph_metrics.ascent - glyph_metrics.descent
-                    w = glyph_metrics.width
+                    gm = @ctx.shadow.get_type_metrics("a" + glyph + "a")
+                    gm2 = @ctx.shadow.get_type_metrics("aa")
+                    h = (gm.ascent - gm.descent + 0.5 ).to_i
+                    w = gm.width - gm2.width
                     if glyph_orientation == 0 || glyph_orientation == 180
                         [w, h]
                     else
